# 2dxPlay
Play konami 2dx files from the command line.


Install with pip and run it from anywhere.  
`pip install 2dxPlay`

### Usage:
```
2dxplay infile.2dx
```
If the file contains more than one wav, it will play all tracks sequentially.  
Press Ctrl+C to pause and enter a track number to jump to, or `q` to quit.
